%define anolis_release 1
Name:           pyproject-rpm-macros
Summary:        RPM macros for PEP 517 Python packages
License:        MIT

%bcond_without tests

# The idea is to follow the spirit of semver
# Given version X.Y.Z:
#   Increment X and reset Y.Z when there is a *major* incompatibility
#   Increment Y and reset Z when new macros or features are added
#   Increment Z when this is a bugfix or a cosmetic change
# Dropping support for EOL Fedoras is *not* considered a breaking change
Version:        1.0.0
Release:        %{anolis_release}%{?dist}

# Macro files
Source001:      macros.pyproject

# Implementation files
Source101:      pyproject_buildrequires.py
Source102:      pyproject_save_files.py
Source103:      pyproject_convert.py
Source104:      pyproject_preprocess_record.py
Source105:      pyproject_construct_toxenv.py
Source106:      pyproject_requirements_txt.py

# Tests
Source201:      test_pyproject_buildrequires.py
Source202:      test_pyproject_save_files.py
Source203:      test_pyproject_requirements_txt.py
Source204:      compare_mandata.py

# Test data
Source301:      pyproject_buildrequires_testcases.yaml
Source302:      pyproject_save_files_test_data.yaml
Source303:      test_RECORD

# Metadata
Source901:      README.md
Source902:      LICENSE

URL:            https://src.fedoraproject.org/rpms/pyproject-rpm-macros

BuildArch:      noarch

%if %{with tests}
BuildRequires: python3dist(pytest)
BuildRequires: python3dist(pyyaml)
BuildRequires: python3dist(packaging)
BuildRequires: python3dist(pip)
BuildRequires: python3dist(setuptools)
BuildRequires: python3dist(toml)
BuildRequires: python3dist(tox-current-env) >= 0.0.6
BuildRequires: python3dist(wheel)
%endif

# We build on top of those:
Requires:      python-rpm-macros
Requires:      python-srpm-macros
Requires:      python3-rpm-macros

# We use the following tools outside of coreutils
Requires:      /usr/bin/find
Requires:      /usr/bin/sed

%description
These macros allow projects that follow the Python packaging specifications
to be packaged as RPMs.

They work for:

* traditional Setuptools-based projects that use the setup.py file,
* newer Setuptools-based projects that have a setup.cfg file,
* general Python projects that use the PEP 517 pyproject.toml file
  (which allows using any build system, such as setuptools, flit or poetry).

These macros replace %%py3_build and %%py3_install,
which only work with setup.py.


%prep
# Not strictly necessary but allows working on file names instead
# of source numbers in install section
%setup -c -T
cp -p %{sources} .

%build
# nothing to do, sources are not buildable

%install
mkdir -p %{buildroot}%{_rpmmacrodir}
mkdir -p %{buildroot}%{_rpmconfigdir}/anolis
install -m 644 macros.pyproject %{buildroot}%{_rpmmacrodir}/
install -m 644 pyproject_buildrequires.py %{buildroot}%{_rpmconfigdir}/anolis/
install -m 644 pyproject_convert.py %{buildroot}%{_rpmconfigdir}/anolis/
install -m 644 pyproject_save_files.py  %{buildroot}%{_rpmconfigdir}/anolis/
install -m 644 pyproject_preprocess_record.py %{buildroot}%{_rpmconfigdir}/anolis/
install -m 644 pyproject_construct_toxenv.py %{buildroot}%{_rpmconfigdir}/anolis/
install -m 644 pyproject_requirements_txt.py %{buildroot}%{_rpmconfigdir}/anolis/

%if %{with tests}
%check
export HOSTNAME="rpmbuild"  # to speedup tox in network-less mock, see rhbz#1856356
%{python3} -m pytest -vv --doctest-modules

# brp-compress is provided as an argument to get the right directory macro expansion
%{python3} compare_mandata.py -f %{_rpmconfigdir}/brp-compress
%endif


%files
%{_rpmmacrodir}/macros.pyproject
%{_rpmconfigdir}/anolis/pyproject_buildrequires.py
%{_rpmconfigdir}/anolis/pyproject_convert.py
%{_rpmconfigdir}/anolis/pyproject_save_files.py
%{_rpmconfigdir}/anolis/pyproject_preprocess_record.py
%{_rpmconfigdir}/anolis/pyproject_construct_toxenv.py
%{_rpmconfigdir}/anolis/pyproject_requirements_txt.py

%doc README.md
%license LICENSE

%changelog
* Thu Mar 02 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 1.0.0-1
- upstream version 1.0.0
